#!/usr/bin/env python

# -*- coding: utf-8 -*-

#

# Print out EXIF information from image files in CSV format
#
#

import sys, os, time, csv, EXIF

tagnames = {
	"EXIF ExifImageLength"	: "Length (pixels)",
	"EXIF ExifImageWidth"	: "Width (pixels)",
	"EXIF ExposureBiasValue": "Exposure Bias",
	"EXIF ExposureMode"	: "Exposure Mode",
	"EXIF ExposureProgram"	: "ExposureProgram",
	"EXIF ExposureTime"	: "Exposure Time (s)",
	"EXIF Flash"		: "Flash",
	"EXIF FocalLength"	: "Focal Length (mm)",
	"EXIF FocalLengthIn35mm": "Focal Lenght In 35mm Eq. (mm)",
	"EXIF GainControl"	: "Gain Control",
	"EXIF ISOSpeedRatings"	: "ISO Speed",
	"EXIF MeteringMode"	: "Metering Mode",
	"EXIF WhiteBalance"	: "White Ballance",
	"Image Make"		: "Make",
	"Image Model"		: "Model"
}


if __name__ == '__main__':
	if len(sys.argv) < 2:
		print "\nThis program takes a list of directories as argument. It scans the directories \
recursively and extracts available EXIF information from image files. The EXIF \
information is then printed to the standard output in CSV format\n"
		print "Usage: %s dir1 [dir2 ...] " % sys.argv[0]
		sys.exit(1)
	else:
		csv = csv.writer(sys.stdout)
		csv.writerow(["Directory","File Name","Date","Time"] + tagnames.values())
		for dir in sys.argv[1:]:
			for root, d, files in os.walk(dir):
				for name in files:
					f = open( os.path.join(root, name), "rb")
					tags = EXIF.process_file(f, details=False)
					f.close()

					if len(tags) > 0:
						l = []
						l.append(root)
						l.append(name)

						try:
							dt = str(tags["EXIF DateTimeOriginal"])
							try:
								tt = time.strptime(dt[:10],"%Y:%m:%d")
								v = time.strftime("%Y-%m-%d", tt)
							except ValueError:
								v = ''
							l.append(v)		# date
							l.append(dt[11:])	# time
						except KeyError:
							l.append('')
							l.append('')


						for t in tagnames:
							try:	
								v = tags[t].printable
								if tags[t].field_type == 5:	# Ratio
									if v.find("/") > 0:
										v = str(eval(v + '.'))
								l.append(v)
							except KeyError:
								l.append('')
	
						csv.writerow(l)
					
